@@ -10,17 +10,24 @@
 #' 
 #' @author Stephen Turner
 #' @keywords NA
+#' 
+#' @param check logical; set to TRUE to check the registration link
+#' @param myurl the URL to visit to print a registration link
 #'   
 #' @return A registration link
 #' 
 #' @examples
+#' \dontrun{
 #' registration()
-#'   
+#' }
+#' 
 #' @export
-registration <- function() {
-    # Where do you keep the registration link?
-    myurl <- "http://stephenturner.us/f/Tmisc-registration-link.txt"
-    reglink <- scan(myurl, what="char", sep="\n", n=1, quiet=TRUE)
-    if (reglink=="") reglink <- NA
-    message(paste0("Please visit the following link to register:\n", reglink))
+registration <- function(check=FALSE, myurl="http://stephenturner.us/files/Tmisc-registration-link.txt") {
+    if (check) {
+        reglink <- scan(myurl, what="char", sep="\n", n=1, quiet=TRUE)
+        if (reglink=="") reglink <- NA
+        message(paste0("Please visit the following link to register:\n", reglink))
+    } else {
+        message("Usage: registration(check=TRUE)")
+    }
 }
